@@ -1,15 +1,19 @@
 from base64 import b64encode
 from collections import defaultdict
 from datetime import datetime
+from typing import Callable, DefaultDict, FrozenSet, List, Tuple
 
 
-def sign_headers(key_id, sign, method, path, headers_to_sign,
-                 hop_by_hop_headers=('keep-alive', 'transfer-encoding', 'connection')):
+def sign_headers(
+        key_id: str, sign: Callable[[bytes], bytes], method: str, path: str,
+        headers_to_sign: Tuple[Tuple[str, str], ...],
+        hop_by_hop_headers: FrozenSet[str] = frozenset(('keep-alive',
+                                                        'transfer-encoding', 'connection'))):
     method_lower = method.lower()
     created = str(int(datetime.now().timestamp()))
 
-    def canonical_headers():
-        headers_lists = defaultdict(list)
+    def canonical_headers() -> Tuple[Tuple[str, str], ...]:
+        headers_lists: DefaultDict[str, List[str]] = defaultdict(list)
         for key, value in headers_to_sign:
             key_lower = key.lower()
             if key_lower not in hop_by_hop_headers:
